CharCodec class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decodeBundle(String encoded) → String
decodeFromBase64({required String encoded, required String charset}) → String
encodeBase64WithCharset({required String base64Input, required String charset}) → String
encodeBundle({required String base64Input, required String charset}) → String
encodeCompressedBundle({required String base64Input, required String charset}) → String
extractCharsetFromBundle(String encoded) → String
getUniqueCharset(String content) → String