RPathToken class

Corresponds to a non-parameterized section of a path specification.

Implemented types

Constructors

RPathToken(String value)
Creates a path token with value.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
A substring of the path specification.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPath(Map<String, String> _) → String
Returns the path representation of this given args.
override
toPattern() → String
Returns the regular expression pattern this matches.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited