SSSS class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

compactDecoder ↔ String
getter/setter pair

Static Methods

decodeSSS(List<Uint8List> parts) → Uint8List
encodeShares({required Uint8List secretBytes, int threshold = 2, int? seed}) → Iterable<Uint8List>